@@ -2,11 +2,23 @@ package Net::GitHub::V2::Issues;
 
 use Moose;
 
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 with 'Net::GitHub::V2::Role';
 
+use URI::Escape;
+
+sub search {
+    my ( $self, $state, $word ) = @_;
+    
+    my $owner = $self->owner;
+    my $repo  = $self->repo;
+    my $url   = "issues/search/$owner/$repo/$state/" . uri_escape($word);
+    
+    return $self->get_json_to_obj( $url, 'issues' );
+}
+
 sub list {
     my ( $self, $state ) = @_;
     
@@ -84,6 +96,18 @@ sub remove_label {
     return $self->get_json_to_obj_authed( "issues/label/remove/$owner/$repo/$label/$id", 'labels' );
 }
 
+sub comment {
+    my ( $self, $id, $text ) = @_;
+    
+    my $owner = $self->owner;
+    my $repo  = $self->repo;
+    
+    return $self->get_json_to_obj_authed( "issues/comment/$owner/$repo/$id",
+        comment => $text,
+        'comment'
+    );
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -117,12 +141,31 @@ For those B<(authentication required)> below, you must set login and token (in L
 
 =over 4
 
+=item search
+
+    my $issues = $issue->search('open', 'test');
+
+search issues
+
 =item list
 
     my $issues = $issue->list('open');
     my $issues = $issue->list('closed');
 
-see a list of issues for a project
+see a list of issues for a project.
+
+each issue is a hash reference which contains:
+
+    'number' => 2,
+    'position' => '1',
+    'state' => 'open',
+    'body' => 'Bug Detail',
+    'created_at' => '2009/04/20 10:00:45 -0700',
+    'updated_at' => '2009/04/20 10:00:45 -0700',
+    'user' => 'foobar',
+    'title' => 'Bug Title',
+    'votes' => 0
+
 
 =item view
 
@@ -160,6 +203,12 @@ edit an existing issue (authentication required)
 
 add/remove a label (authentication required)
 
+=item comment
+
+    my $comment = $issue->comment( $number, 'this is amazing' );
+
+comment on issues
+
 =back
 
 =head1 AUTHOR
@@ -171,4 +220,4 @@ Fayland Lam, C<< <fayland at gmail.com> >>
 Copyright 2009 Fayland Lam, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
